@@ -20,7 +20,7 @@ class Database:
       o = True
       for l in r:
         try:
-          if not cb(json.loads(l)): o = False
+          if cb(json.loads(l)): o = False
           else: o = True
         except: None
         if o: w.write(l)
